## Aliases

The following lists all implemented metrics, by alias. These can be used when composing metrics using [metric syntax strings](http://ioverho.github.io/prob_conf_mat/How%20To%20Guides/metric_syntax.html).

@@metrics_table@@

## Abstract Base Class

::: prob_conf_mat.metrics.abc.Metric
    options:
        heading_level: 3

::: prob_conf_mat.metrics.abc.AveragedMetric
    options:
        heading_level: 3

## Metric Instances

@@metrics_list@@
